==> eam-wshub-proxyclient-11.7-2-sources.jar: net/datastream/schemas/mp_entities/customerrentaladjustmentdefault_001/CustomerRentalAdjustmentDefault.java <==

package net.datastream.schemas.mp_entities.customerrentaladjustmentdefault_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.CUSTOMERRENTALID_Type;
import net.datastream.schemas.mp_fields.STATUS_Type;
import net.datastream.schemas.mp_fields.TAXID_Type;
import net.datastream.schemas.mp_fields.TYPE_Type;
import org.openapplications.oagis_segments.DATETIME;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CUSTOMERRENTALID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ADJUSTMENTDATE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ADJUSTMENTSTATUS"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ADJUSTMENTRSTATUS"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ADJUSTMENTTYPE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TAXID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TAXPERCENTAGE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}RSTATUS" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CURRENCYCODE" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "customerrentalid",
    "adjustmentdate",
    "adjustmentstatus",
    "adjustmentrstatus",
    "adjustmenttype",
    "taxid",
    "taxpercentage",
    "rstatus",
    "currencycode"
})
@XmlRootElement(name = "CustomerRentalAdjustmentDefault")
public class CustomerRentalAdjustmentDefault {

    @XmlElement(name = "CUSTOMERRENTALID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected CUSTOMERRENTALID_Type customerrentalid;
    @XmlElement(name = "ADJUSTMENTDATE", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected DATETIME adjustmentdate;
    @XmlElement(name = "ADJUSTMENTSTATUS", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected STATUS_Type adjustmentstatus;
    @XmlElement(name = "ADJUSTMENTRSTATUS", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected STATUS_Type adjustmentrstatus;
    @XmlElement(name = "ADJUSTMENTTYPE", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected TYPE_Type adjustmenttype;
    @XmlElement(name = "TAXID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected TAXID_Type taxid;
    @XmlElement(name = "TAXPERCENTAGE", namespace = "http://schemas.datastream.net/MP_fields")
    protected QUANTITY taxpercentage;
    @XmlElement(name = "RSTATUS", namespace = "http://schemas.datastream.net/MP_fields")
    protected STATUS_Type rstatus;
    @XmlElement(name = "CURRENCYCODE", namespace = "http://schemas.datastream.net/MP_fields")
    protected String currencycode;

    /**
     * Gets the value of the customerrentalid property.
     * 
     * @return
     *     possible object is
     *     {@link CUSTOMERRENTALID_Type }
     *     
     */
    public CUSTOMERRENTALID_Type getCUSTOMERRENTALID() {
        return customerrentalid;
    }

    /**
     * Sets the value of the customerrentalid property.
     * 
     * @param value
     *     allowed object is
     *     {@link CUSTOMERRENTALID_Type }
     *     
     */
    public void setCUSTOMERRENTALID(CUSTOMERRENTALID_Type value) {
        this.customerrentalid = value;
    }

    /**
     * Gets the value of the adjustmentdate property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getADJUSTMENTDATE() {
        return adjustmentdate;
    }

    /**
     * Sets the value of the adjustmentdate property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setADJUSTMENTDATE(DATETIME value) {
        this.adjustmentdate = value;
    }

    /**
     * Gets the value of the adjustmentstatus property.
     * 
     * @return
     *     possible object is
     *     {@link STATUS_Type }
     *     
     */
    public STATUS_Type getADJUSTMENTSTATUS() {
        return adjustmentstatus;
    }

    /**
     * Sets the value of the adjustmentstatus property.
     * 
     * @param value
     *     allowed object is
     *     {@link STATUS_Type }
     *     
     */
    public void setADJUSTMENTSTATUS(STATUS_Type value) {
        this.adjustmentstatus = value;
    }

    /**
     * Gets the value of the adjustmentrstatus property.
     * 
     * @return
     *     possible object is
     *     {@link STATUS_Type }
     *     
     */
    public STATUS_Type getADJUSTMENTRSTATUS() {
        return adjustmentrstatus;
    }

    /**
     * Sets the value of the adjustmentrstatus property.
     * 
     * @param value
     *     allowed object is
     *     {@link STATUS_Type }
     *     
     */
    public void setADJUSTMENTRSTATUS(STATUS_Type value) {
        this.adjustmentrstatus = value;
    }

    /**
     * Gets the value of the adjustmenttype property.
     * 
     * @return
     *     possible object is
     *     {@link TYPE_Type }
     *     
     */
    public TYPE_Type getADJUSTMENTTYPE() {
        return adjustmenttype;
    }

    /**
     * Sets the value of the adjustmenttype property.
     * 
     * @param value
     *     allowed object is
     *     {@link TYPE_Type }
     *     
     */
    public void setADJUSTMENTTYPE(TYPE_Type value) {
        this.adjustmenttype = value;
    }

    /**
     * Gets the value of the taxid property.
     * 
     * @return
     *     possible object is
     *     {@link TAXID_Type }
     *     
     */
    public TAXID_Type getTAXID() {
        return taxid;
    }

    /**
     * Sets the value of the taxid property.
     * 
     * @param value
     *     allowed object is
     *     {@link TAXID_Type }
     *     
     */
    public void setTAXID(TAXID_Type value) {
        this.taxid = value;
    }

    /**
     * Gets the value of the taxpercentage property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getTAXPERCENTAGE() {
        return taxpercentage;
    }

    /**
     * Sets the value of the taxpercentage property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setTAXPERCENTAGE(QUANTITY value) {
        this.taxpercentage = value;
    }

    /**
     * Gets the value of the rstatus property.
     * 
     * @return
     *     possible object is
     *     {@link STATUS_Type }
     *     
     */
    public STATUS_Type getRSTATUS() {
        return rstatus;
    }

    /**
     * Sets the value of the rstatus property.
     * 
     * @param value
     *     allowed object is
     *     {@link STATUS_Type }
     *     
     */
    public void setRSTATUS(STATUS_Type value) {
        this.rstatus = value;
    }

    /**
     * Gets the value of the currencycode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCURRENCYCODE() {
        return currencycode;
    }

    /**
     * Sets the value of the currencycode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCURRENCYCODE(String value) {
        this.currencycode = value;
    }

}

==> eam-wshub-proxyclient-12.1-1-sources.jar: net/datastream/schemas/mp_entities/customerrentaladjustmentdefault_001/CustomerRentalAdjustmentDefault.java <==

package net.datastream.schemas.mp_entities.customerrentaladjustmentdefault_001;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlRootElement;
import jakarta.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.CUSTOMERRENTALID_Type;
import net.datastream.schemas.mp_fields.STATUS_Type;
import net.datastream.schemas.mp_fields.TAXID_Type;
import net.datastream.schemas.mp_fields.TYPE_Type;
import org.openapplications.oagis_segments.DATETIME;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType>
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <sequence>
 *         <element ref="{http://schemas.datastream.net/MP_fields}CUSTOMERRENTALID"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}ADJUSTMENTDATE"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}ADJUSTMENTSTATUS"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}ADJUSTMENTRSTATUS"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}ADJUSTMENTTYPE"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}TAXID"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}TAXPERCENTAGE" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}RSTATUS" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}CURRENCYCODE" minOccurs="0"/>
 *       </sequence>
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "customerrentalid",
    "adjustmentdate",
    "adjustmentstatus",
    "adjustmentrstatus",
    "adjustmenttype",
    "taxid",
    "taxpercentage",
    "rstatus",
    "currencycode"
})
@XmlRootElement(name = "CustomerRentalAdjustmentDefault")
public class CustomerRentalAdjustmentDefault {

    @XmlElement(name = "CUSTOMERRENTALID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected CUSTOMERRENTALID_Type customerrentalid;
    @XmlElement(name = "ADJUSTMENTDATE", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected DATETIME adjustmentdate;
    @XmlElement(name = "ADJUSTMENTSTATUS", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected STATUS_Type adjustmentstatus;
    @XmlElement(name = "ADJUSTMENTRSTATUS", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected STATUS_Type adjustmentrstatus;
    @XmlElement(name = "ADJUSTMENTTYPE", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected TYPE_Type adjustmenttype;
    @XmlElement(name = "TAXID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected TAXID_Type taxid;
    @XmlElement(name = "TAXPERCENTAGE", namespace = "http://schemas.datastream.net/MP_fields")
    protected QUANTITY taxpercentage;
    @XmlElement(name = "RSTATUS", namespace = "http://schemas.datastream.net/MP_fields")
    protected STATUS_Type rstatus;
    @XmlElement(name = "CURRENCYCODE", namespace = "http://schemas.datastream.net/MP_fields")
    protected String currencycode;

    /**
     * Gets the value of the customerrentalid property.
     * 
     * @return
     *     possible object is
     *     {@link CUSTOMERRENTALID_Type }
     *     
     */
    public CUSTOMERRENTALID_Type getCUSTOMERRENTALID() {
        return customerrentalid;
    }

    /**
     * Sets the value of the customerrentalid property.
     * 
     * @param value
     *     allowed object is
     *     {@link CUSTOMERRENTALID_Type }
     *     
     */
    public void setCUSTOMERRENTALID(CUSTOMERRENTALID_Type value) {
        this.customerrentalid = value;
    }

    /**
     * Gets the value of the adjustmentdate property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getADJUSTMENTDATE() {
        return adjustmentdate;
    }

    /**
     * Sets the value of the adjustmentdate property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setADJUSTMENTDATE(DATETIME value) {
        this.adjustmentdate = value;
    }

    /**
     * Gets the value of the adjustmentstatus property.
     * 
     * @return
     *     possible object is
     *     {@link STATUS_Type }
     *     
     */
    public STATUS_Type getADJUSTMENTSTATUS() {
        return adjustmentstatus;
    }

    /**
     * Sets the value of the adjustmentstatus property.
     * 
     * @param value
     *     allowed object is
     *     {@link STATUS_Type }
     *     
     */
    public void setADJUSTMENTSTATUS(STATUS_Type value) {
        this.adjustmentstatus = value;
    }

    /**
     * Gets the value of the adjustmentrstatus property.
     * 
     * @return
     *     possible object is
     *     {@link STATUS_Type }
     *     
     */
    public STATUS_Type getADJUSTMENTRSTATUS() {
        return adjustmentrstatus;
    }

    /**
     * Sets the value of the adjustmentrstatus property.
     * 
     * @param value
     *     allowed object is
     *     {@link STATUS_Type }
     *     
     */
    public void setADJUSTMENTRSTATUS(STATUS_Type value) {
        this.adjustmentrstatus = value;
    }

    /**
     * Gets the value of the adjustmenttype property.
     * 
     * @return
     *     possible object is
     *     {@link TYPE_Type }
     *     
     */
    public TYPE_Type getADJUSTMENTTYPE() {
        return adjustmenttype;
    }

    /**
     * Sets the value of the adjustmenttype property.
     * 
     * @param value
     *     allowed object is
     *     {@link TYPE_Type }
     *     
     */
    public void setADJUSTMENTTYPE(TYPE_Type value) {
        this.adjustmenttype = value;
    }

    /**
     * Gets the value of the taxid property.
     * 
     * @return
     *     possible object is
     *     {@link TAXID_Type }
     *     
     */
    public TAXID_Type getTAXID() {
        return taxid;
    }

    /**
     * Sets the value of the taxid property.
     * 
     * @param value
     *     allowed object is
     *     {@link TAXID_Type }
     *     
     */
    public void setTAXID(TAXID_Type value) {
        this.taxid = value;
    }

    /**
     * Gets the value of the taxpercentage property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getTAXPERCENTAGE() {
        return taxpercentage;
    }

    /**
     * Sets the value of the taxpercentage property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setTAXPERCENTAGE(QUANTITY value) {
        this.taxpercentage = value;
    }

    /**
     * Gets the value of the rstatus property.
     * 
     * @return
     *     possible object is
     *     {@link STATUS_Type }
     *     
     */
    public STATUS_Type getRSTATUS() {
        return rstatus;
    }

    /**
     * Sets the value of the rstatus property.
     * 
     * @param value
     *     allowed object is
     *     {@link STATUS_Type }
     *     
     */
    public void setRSTATUS(STATUS_Type value) {
        this.rstatus = value;
    }

    /**
     * Gets the value of the currencycode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCURRENCYCODE() {
        return currencycode;
    }

    /**
     * Sets the value of the currencycode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCURRENCYCODE(String value) {
        this.currencycode = value;
    }

}
